Discover Packages
github.com/calebdoxsey/tutorials
trie
package
Version:
v0.0.0-...-3633571
Opens a new window with list of versions in this module.
Published: Aug 15, 2019
License: MIT
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
Documentation
¶
Key returns the current key
Next moves the iterator to the next key value pair in the trie
Value returns the current value
Delete deletes the specified key from the trie.
func (t *Trie ) Get(key []byte ) interface{}
Get returns the value associated with the specified key or nil.
Iterator returns an iterator that can be used to traverse
the trie in sorted order. The iterator starts before the
first key value pair, so Next() should be called before
Key() and Value()
Len returns the number of key value pairs in the trie.
Set inserts or replaces the specified key and value.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.